@@ -229,7 +229,7 @@ class Iterator(BaseElement):
         self,
         iterator: typing.Union[typing.Iterable, Lazy],
         loopvariable: str,
-        content: BaseElement,
+        content: typing.Union[BaseElement, Lazy],
     ):
         self.iterator = iterator
         self.loopvariable = loopvariable
@@ -264,7 +264,7 @@ class WithContext(BaseElement):
 
 
 def treewalk(
-    element: typing.List,
+    element: BaseElement,
     ancestors: typing.Tuple[BaseElement, ...],
     filter_func: typing.Optional[
         typing.Callable[[BaseElement, typing.Tuple[BaseElement, ...]], bool]
@@ -284,7 +284,7 @@ def treewalk(
                 matchelements.append((i, e))
             if isinstance(e, HTMLElement):
                 yield from treewalk(
-                    list(e.attributes.values()),
+                    BaseElement(*e.attributes.values()),
                     ancestors + (e,),
                     filter_func=filter_func,
                     apply=apply,
@@ -392,10 +392,6 @@ def _handle_exception(exception, context):
     import sys
     import traceback
 
-    def default_handler(context, message):
-        traceback.print_exc()
-        print(message, file=sys.stderr)
-
     last_obj = None
     indent = 0
     message = []
@@ -417,7 +413,7 @@ def _handle_exception(exception, context):
     message.append(" " * indent + str(exception))
     message = "\n".join(message)
 
-    context.get(EXCEPTION_HANDLER_NAME, default_handler)(context, message)
+    context.get(EXCEPTION_HANDLER_NAME, default_exception_handler)(context, message)
 
     yield (
         '<pre style="border: solid 1px red; color: red; padding: 1rem; '
@@ -426,3 +422,11 @@ def _handle_exception(exception, context):
         "</pre>"
         f'<script>alert("Error: {conditional_escape(exception)}")</script>'
     )
+
+
+def default_exception_handler(context, message):
+    import sys
+    import traceback
+
+    traceback.print_exc()
+    print(message, file=sys.stderr)
